@@ -1,14 +1,13 @@
-from typing import Iterable, List, Optional, Set, cast
+from typing import Iterable, Optional, cast
 
 import pkg_resources
-import urwid
 
 from ovshell import api, device, ovos, process, settings
 from ovshell.api import Extension, ExtensionFactory, OpenVarioShell, ScreenManager
 
 
 class ExtensionManagerImpl(api.ExtensionManager):
-    _extensions: List[Extension]
+    _extensions: list[Extension]
 
     def __init__(self):
         self._extensions = []
@@ -28,14 +27,17 @@ class AppManagerImpl(api.AppManager):
     def __init__(self, shell: OpenVarioShell) -> None:
         self.shell = shell
 
-    def list(self) -> Iterable[api.AppInfo]:
+    def list_apps(self) -> Iterable[api.AppInfo]:
         appinfos = []
         allpinned = self._get_pinned()
         for ext in self.shell.extensions.list_extensions():
             for app in ext.list_apps():
                 appid = f"{ext.id}.{app.name}"
                 appinfo = api.AppInfo(
-                    id=appid, app=app, extension=ext, pinned=appid in allpinned,
+                    id=appid,
+                    app=app,
+                    extension=ext,
+                    pinned=appid in allpinned,
                 )
                 appinfos.append(appinfo)
 
@@ -43,7 +45,7 @@ class AppManagerImpl(api.AppManager):
         return appinfos
 
     def get(self, id: str) -> Optional[api.AppInfo]:
-        for appinfo in self.list():
+        for appinfo in self.list_apps():
             if appinfo.id == id:
                 return appinfo
         return None
@@ -62,10 +64,10 @@ class AppManagerImpl(api.AppManager):
         pinned.remove(app.id)
         self._set_pinned(pinned, persist)
 
-    def install_new_apps(self) -> List[api.AppInfo]:
+    def install_new_apps(self) -> list[api.AppInfo]:
         installed = self.shell.settings.get("ovshell.installed_apps", list) or []
         newapps = []
-        for appinfo in self.list():
+        for appinfo in self.list_apps():
             if appinfo.id in installed:
                 continue
 
@@ -79,10 +81,10 @@ class AppManagerImpl(api.AppManager):
 
         return newapps
 
-    def _get_pinned(self) -> Set[str]:
+    def _get_pinned(self) -> set[str]:
         return set(self.shell.settings.get("ovshell.pinned_apps", list) or [])
 
-    def _set_pinned(self, pinned: Set[str], persist: bool = False):
+    def _set_pinned(self, pinned: set[str], persist: bool = False):
         self.shell.settings.set(
             "ovshell.pinned_apps", sorted(pinned) or [], save=persist
         )
@@ -108,6 +110,3 @@ class OpenvarioShellImpl(OpenVarioShell):
         # Start extensions
         for ext in self.extensions.list_extensions():
             ext.start()
-
-    def quit(self) -> None:
-        raise urwid.ExitMainLoop()
