@@ -1,11 +1,15 @@
 import enum
 from abc import abstractmethod
 from dataclasses import dataclass, field
-from typing import Any, Callable, Dict, List, Sequence
+from typing import Any, Callable, Sequence
 
 from typing_extensions import Protocol
 
 
+class ConnmanNotAvailableException(Exception):
+    pass
+
+
 class ConnmanState(enum.Enum):
     UNKNOWN = "unknown"
     OFFLINE = "offline"
@@ -40,7 +44,7 @@ class ConnmanService:
     name: str
     auto_connect: bool = False
     favorite: bool = False
-    security: List[str] = field(default_factory=list)
+    security: list[str] = field(default_factory=list)
     state: ConnmanServiceState = ConnmanServiceState.IDLE
     strength: int = 0
 
@@ -50,7 +54,9 @@ class ConnmanManager(Protocol):
 
     @abstractmethod
     async def setup(self) -> None:
-        """Subscripe to signals in order to keep track of services and technologies"""
+        """Subscripe to signals in order to keep track of services and technologies
+
+        If connman service is not available, raise ConnmanNotAvailable exception"""
 
     @abstractmethod
     def teardown(self) -> None:
@@ -126,8 +132,8 @@ class ConnmanAgent(Protocol):
 
     @abstractmethod
     async def request_input(
-        self, service: ConnmanService, fields: Dict[str, Dict[str, str]]
-    ) -> Dict[str, Any]:
+        self, service: ConnmanService, fields: dict[str, dict[str, str]]
+    ) -> dict[str, Any]:
         """Request input from the user"""
 
     @abstractmethod
