@@ -1,5 +1,5 @@
 import asyncio
-from typing import Callable, List
+from typing import Callable
 
 import urwid
 
@@ -58,7 +58,10 @@ class WelcomeWizardStep(WizardStepWidget):
             [
                 ("pack", urwid.Text(welcome_msg)),
                 ("pack", urwid.Divider()),
-                ("pack", _button_row([self.make_next_button("Start")]),),
+                (
+                    "pack",
+                    _button_row([self.make_next_button("Start")]),
+                ),
             ]
         )
         super().__init__(content)
@@ -97,7 +100,10 @@ class OrientationWizardStep(WizardStepWidget):
             [
                 ("pack", urwid.Text(msg)),
                 ("pack", urwid.Divider()),
-                ("pack", _button_row([self.make_next_button("Skip")]),),
+                (
+                    "pack",
+                    _button_row([self.make_next_button("Skip")]),
+                ),
                 ("pack", urwid.Divider()),
                 (len(orient_walker), self.orient_lb),
             ]
@@ -150,7 +156,10 @@ class CalibrateTouchWizardStep(WizardStepWidget):
             [
                 ("pack", urwid.Text(msg)),
                 ("pack", urwid.Divider()),
-                ("pack", _button_row([self.make_next_button("Skip"), cal_btn]),),
+                (
+                    "pack",
+                    _button_row([self.make_next_button("Skip"), cal_btn]),
+                ),
             ]
         )
         super().__init__(content)
@@ -193,7 +202,10 @@ class CalibrateSensorsWizardStep(WizardStepWidget):
             [
                 ("pack", urwid.Text(msg)),
                 ("pack", urwid.Divider()),
-                ("pack", _button_row([self.make_next_button("Skip"), cal_btn]),),
+                (
+                    "pack",
+                    _button_row([self.make_next_button("Skip"), cal_btn]),
+                ),
             ]
         )
         super().__init__(content)
@@ -239,13 +251,14 @@ class SetupActivity(api.Activity):
         )
 
         self.frame = urwid.Frame(
-            self.content_pile, header=widget.ActivityHeader("Setup wizard"),
+            self.content_pile,
+            header=widget.ActivityHeader("Setup wizard"),
         )
 
         self._switch_step(0)
         return self.frame
 
-    def _setup_steps(self, steps: List[WizardStepWidget]) -> None:
+    def _setup_steps(self, steps: list[WizardStepWidget]) -> None:
         assert len(steps) > 0
         self._steps = {}
         for n, step_w in enumerate(steps):
@@ -296,13 +309,13 @@ class SetupActivity(api.Activity):
         self.shell.screen.pop_activity()
 
 
-def _button_row(buttons: List[urwid.Widget]) -> urwid.GridFlow:
+def _button_row(buttons: list[urwid.Widget]) -> urwid.GridFlow:
     return urwid.GridFlow(buttons, 14, 1, 1, "left")
 
 
 class CommandRunnerActivity(api.Activity):
-    _success_handlers: List[Callable[[], None]]
-    _failure_handlers: List[Callable[[], None]]
+    _success_handlers: list[Callable[[], None]]
+    _failure_handlers: list[Callable[[], None]]
 
     def __init__(
         self,
@@ -310,7 +323,7 @@ class CommandRunnerActivity(api.Activity):
         title: str,
         description: str,
         command: str,
-        args: List[str],
+        args: list[str],
     ) -> None:
         self.shell = shell
         self.title = title
@@ -328,7 +341,10 @@ class CommandRunnerActivity(api.Activity):
 
     def get_modal_opts(self) -> api.ModalOptions:
         return api.ModalOptions(
-            align="center", width=("relative", 90), valign="middle", height="pack",
+            align="center",
+            width=("relative", 90),
+            valign="middle",
+            height="pack",
         )
 
     def activate(self) -> None:
@@ -340,7 +356,7 @@ class CommandRunnerActivity(api.Activity):
     def on_failure(self, handler: Callable[[], None]) -> None:
         self._failure_handlers.append(handler)
 
-    async def run(self, command: str, args: List[str]) -> None:
+    async def run(self, command: str, args: list[str]) -> None:
         proc = await self.shell.os.run(command, args)
         result = await proc.wait()
         loop = asyncio.get_event_loop()
