@@ -1,6 +1,4 @@
-from typing import Dict, Optional
-
-import pytest
+from typing import Optional
 
 from ovshell import testing
 from ovshell_core import aboutapp
@@ -9,7 +7,7 @@ from tests.fixtures.urwid import UrwidMock
 
 
 class SystemInfoStub(SystemInfo):
-    pkg_versions: Dict[str, str]
+    pkg_versions: dict[str, str]
 
     def __init__(self) -> None:
         self.pkg_versions = {}
@@ -41,7 +39,6 @@ class TestAboutApp:
 
 
 class TestAboutActivity:
-    @pytest.mark.asyncio
     async def test_wizard_diplay(self, ovshell: testing.OpenVarioShellStub) -> None:
         # GIVEN
         urwid_mock = UrwidMock()
