@@ -1,6 +1,5 @@
 from pathlib import Path
 
-import pytest
 import urwid
 
 from ovshell import testing
@@ -73,7 +72,7 @@ class TestOrientationWizardStep:
         urwid_mock.keypress(step, ["down", "down", "enter"])
 
         # THEN
-        with open(ovshell.os.path("//sys/class/graphics/fbcon/rotate_all"), "r") as f:
+        with open(ovshell.os.path("//sys/class/graphics/fbcon/rotate_all")) as f:
             writtenrot = f.read()
 
         assert writtenrot == "3"
@@ -88,7 +87,6 @@ class TestCalibrateTouchWizardStep:
     def setup_method(self):
         self.completed = False
 
-    @pytest.mark.asyncio
     async def test_calibrate(self, ovshell: testing.OpenVarioShellStub) -> None:
         # GIVEN
         urwid_mock = UrwidMock()
@@ -116,7 +114,6 @@ class TestCalibrateSensorsWizardStep:
     def setup_method(self):
         self.completed = False
 
-    @pytest.mark.asyncio
     async def test_calibrate(self, ovshell: testing.OpenVarioShellStub) -> None:
         # GIVEN
         urwid_mock = UrwidMock()
@@ -144,7 +141,6 @@ class TestCommandRunnerActivity:
     def setup_method(self):
         self.completed = False
 
-    @pytest.mark.asyncio
     async def test_success(self, ovshell: testing.OpenVarioShellStub) -> None:
         # GIVEN
         urwid_mock = UrwidMock()
@@ -162,7 +158,6 @@ class TestCommandRunnerActivity:
         # THEN
         assert ovshell.screen.stub_top_activity() is None
 
-    @pytest.mark.asyncio
     async def test_failure(self, ovshell: testing.OpenVarioShellStub) -> None:
         # GIVEN
         urwid_mock = UrwidMock()
