@@ -1,6 +1,6 @@
 import asyncio
 from dataclasses import dataclass
-from typing import List, Optional
+from typing import Optional
 
 import pytest
 
@@ -14,10 +14,10 @@ from .stubs import AutomountWatcherStub
 
 class DownloaderStub(Downloader):
     stub_last_filter: Optional[DownloadFilter] = None
-    stub_files: Optional[List[FileInfo]] = None
+    stub_files: Optional[list[FileInfo]] = None
     failing = False
 
-    def list_logs(self, filter: DownloadFilter) -> List[FileInfo]:
+    def list_logs(self, filter: DownloadFilter) -> list[FileInfo]:
         self.stub_last_filter = filter
         return self.stub_files or []
 
@@ -26,7 +26,7 @@ class DownloaderStub(Downloader):
         await asyncio.sleep(0)
         progress.progress(file.size // 2)
         if self.failing:
-            raise IOError("Download failed")
+            raise OSError("Download failed")
         await asyncio.sleep(0)
         progress.progress(file.size // 2)
 
@@ -65,7 +65,6 @@ def test_app_start(ovshell: testing.OpenVarioShellStub) -> None:
     assert isinstance(act, LogDownloaderActivity)
 
 
-@pytest.mark.asyncio
 async def test_activity_fs_mounting(
     activity_testbed: LogDownloaderActivityTestbed,
 ) -> None:
@@ -80,7 +79,6 @@ async def test_activity_fs_mounting(
     assert "Please insert USB storage" in urwid_mock.render(w)
 
 
-@pytest.mark.asyncio
 async def test_activity_list_files(
     activity_testbed: LogDownloaderActivityTestbed,
 ) -> None:
@@ -104,7 +102,6 @@ async def test_activity_list_files(
     assert "two.igc" in rendered
 
 
-@pytest.mark.asyncio
 async def test_activity_unmount(
     activity_testbed: LogDownloaderActivityTestbed,
 ) -> None:
@@ -128,7 +125,6 @@ async def test_activity_unmount(
     assert "Please insert USB storage" in urwid_mock.render(w)
 
 
-@pytest.mark.asyncio
 async def test_activity_change_settings(
     activity_testbed: LogDownloaderActivityTestbed,
 ) -> None:
@@ -152,7 +148,6 @@ async def test_activity_change_settings(
     assert filt == {"new": False, "igc": False, "nmea": False}
 
 
-@pytest.mark.asyncio
 async def test_activity_download(
     activity_testbed: LogDownloaderActivityTestbed,
 ) -> None:
@@ -179,7 +174,6 @@ async def test_activity_download(
     assert "Done" in urwid_mock.render(w)
 
 
-@pytest.mark.asyncio
 async def test_activity_download_error(
     activity_testbed: LogDownloaderActivityTestbed,
 ) -> None:
