@@ -1,8 +1,6 @@
 import asyncio
-from typing import List
+from unittest import mock
 
-import mock
-import pytest
 import urwid
 
 from ovshell import api
@@ -143,7 +141,6 @@ def test_push_dialog() -> None:
     assert "Dialog Title" not in urwid_mock.render(mainloop.widget)
 
 
-@pytest.mark.asyncio
 async def test_spawn_task() -> None:
     # GIVEN
     mainloop = mock.Mock(name="MainLoop")
@@ -152,7 +149,7 @@ async def test_spawn_task() -> None:
     act1 = ActivityStub("Main Activity")
     screen.push_activity(act1)
 
-    log: List[str] = []
+    log: list[str] = []
 
     async def infinite_loop() -> None:
         log.append("started")
